<?php
/**
 * Loadscreen Plugin for MPAseco and Xaseco2
 * This Plugin displays a loadscreen at the end of a Map
 * Author: Lukas Kremsmayr
 * Version: v0.1 (25.02.2013) 
 * Dependencies: none
 */

/* Used Manialinks:
   99958001 Widget Id
*/

//dummy plugin class for XAseco
if (!class_exists('Plugin')){
	class Plugin{
		var $author, $version, $description, $Aseco, $dependencies;
		function setAuthor($auth){
			$this->author = $auth;
		}
		function setVersion($version){
			$this->version = $version;
		}
			function setDescription($description){
			$this->description = $description;
		}
		function addDependence($plugin_name, $id_variable){
			if (!$this->dependencies) $this->dependencies = array();
	 	   $this->dependencies[$id_variable] = $plugin_name;
		}
		function checkDependencies(){
			if (!$this->dependencies) return;
			foreach ($this->dependencies as $id_variable => $plugin_name) {
				$checkFor = null;
				eval('global $'.$id_variable.'; $checkFor = $'.$id_variable.';');
				if (!$checkFor){
					$this->Aseco->console('['.get_class($this).'] Unmet Dependency! With your current configuration you need to activate "'.$plugin_name.'" to run this plugin!');
					die();
				}
			}
		}
	}	
}
	
class Loadscreen extends Plugin {
  private $images;
  private $startTime;
  private $widgetId;
  private $timeOffset;
  private $visible;
  public function init(){
    $this->pluginVersion = '0.01';	
    $this->pluginAuthor = 'Lukas Kremsmayr';
    $this->widgetId = "99958001";
    $this->visible = false;
    $this->images = array();
    $this->startTime = time() * 2;
  }
  
	public function mpasecoStartup(){
	 /* Load Config File */
   if(file_exists('loadscreen.xml'))
    $conf_file = 'loadscreen.xml';
   else if(file_exists('plugins/loadscreen.xml'))
    $conf_file = 'plugins/loadscreen.xml';
   else
    $conf_file = 'configs/plugins/loadscreen.xml';
    
    if (file_exists($conf_file)) { 
     $this->Aseco->console('Load loadscreen config file [' . $conf_file . ']');
  	 if ($xml = $this->Aseco->xml_parser->parseXml($conf_file)) {
  	     /* Storage Images in $this->images[] */
         $i = 0;
         foreach ($xml['LOADSCREEN']['LOADSCREEN_IMAGES'][0]['LOADSCREEN_IMAGE'] as $img) {
     	     $this->images[$i] = $img;
     	     $i++;
     	  }       
        /* Xml Settings_ */
        $this->timeOffset  = $xml['LOADSCREEN']['LOADSCREEN_SETTINGS'][0]['TIME_OFFSET'][0];
    } else {
    trigger_error('Could not read/parse loadscreen config file ' . $conf_file . ' !', E_USER_WARNING);
    }
   } else {
    trigger_error('Could not find loadscreen config file ' . $conf_file . ' !', E_USER_WARNING);
   }    
	}

  public function playerConnect($player) {
    $this->showWidget($player->login, 2);    
  }  
  public function endMap() {
    $this->startTime = (int) $this->timeOffset + time();  
  } 
  public function beginMap() {
    $this->startTime = time() * 2;  
    $this->visible = false;
    $this->showWidget(false, 1);
  }     
  public function everySecond() {
    if(time() >= $this->startTime && !$this->visible){
      $this->showWidget();
      $this->visible = true;
    } 
  }      
  /* action: 0 = show, 1 = hide, 2 = preload */
  private function showWidget($login = false, $action = 0){
    $xml  = '<?xml version="1.0" encoding="UTF-8"?>';                                       
    $xml .= '<manialinks>';
    $xml .= '  <manialink id='.$this->widgetId.'>';
    switch($action){
      case 0: $xml .= $this->showLoadscreen(); break;
      case 2: $xml .= $this->preload();        break;
    }
    $xml .= '  </manialink>';  
    $xml .= getCustomUIBlock();
    $xml .= '</manialinks>';                      
    $close = false;
    $timeout = 0;
    if($login)                                                                   
      $this->Aseco->client->query('SendDisplayManialinkPageToLogin', $login, $xml, ($timeout * 1000), $close);   
    else
      $this->Aseco->client->query('SendDisplayManialinkPage', $xml, ($timeout * 1000), $close);   
  }
  private function showLoadscreen(){
    $index = rand(0, count($this->images) - 1);
    $xml = '<frame posn="-64 48 25">';
    $xml .= '<quad  posn="0 0 0" sizen="128 96"  image="'.$this->images[$index].'"/>';
    $xml .= '</frame>';
   
    return $xml;
  }
  private function preload(){
    $xml = '<frame posn="200 200 -2000">';
    foreach ($this->images as $image){
      $xml .= '<quad  posn="0 0 0" sizen="200 200"  image="'.$image.'"/>';
    } 
    $xml .= '</frame>';
   
    return $xml;
  }
}

global $loadscreen;
$loadscreen = new Loadscreen();
$loadscreen->init();
$loadscreen->setAuthor($loadscreen->pluginAuthor); 
$loadscreen->setVersion($loadscreen->pluginVersion);
$loadscreen->setDescription('Displays a Loadscreen at the end of a Map.');
	
/* Register the used Events */
Aseco::registerEvent('onStartup', 'loadscreen_mpasecoStartup');  
Aseco::registerEvent('onPlayerConnect', 'loadscreen_playerConnect');
Aseco::registerEvent('onPlayerDisconnect', 'loadscreen_changePointlimit');
Aseco::registerEvent('onEndMap', 'loadscreen_endMap');
Aseco::registerEvent('onBeginMap', 'loadscreen_beginMap');
Aseco::registerEvent('onEverySecond', 'loadscreen_everySecond');             
                          
/* Events: */  
function loadscreen_mpasecoStartup($aseco){
	global $loadscreen;
	if (!$loadscreen->Aseco){
			$loadscreen->Aseco = $aseco;
	}
	$loadscreen->mpasecoStartup();
}

function loadscreen_playerConnect($aseco, $player){
	global $loadscreen;
	$loadscreen->playerConnect($player);
}       

function loadscreen_endMap(){
	global $loadscreen;
	$loadscreen->endMap();
}  

function loadscreen_beginMap(){
	global $loadscreen;
	$loadscreen->beginMap();
}  

function loadscreen_everySecond(){
	global $loadscreen;
	$loadscreen->everySecond();
}       	     	
?>